@@ -617,9 +617,6 @@ proc logEdit_unset idx {
 # ipos	the position of the entry in the list of olog entries
 proc logEdit_edShell {idx ipos} {
    global LGL_Shell
-   global projects
-   global activities
-   global allcontacts
    set win $LGL_Shell($idx-shell).ed$ipos
 
    if {[winfo exists $win]} {
@@ -693,7 +690,7 @@ proc logEdit_edShell {idx ipos} {
          $win.body.eId insert 0 \
 	 		[clock format [clock seconds] -format %Y%m%d%H%M%S]
    }
-   grid $win.body.lDescription -row $irow -column 0 -sticky e
+   grid $win.body.lDescription -row $irow -column 0 -sticky ensw
    pack $win.body.frm.vscr -side left -fill y -expand 1
    grid $win.body.frm -row $irow -column 1 -sticky nsew
    pack $win.body -side top -fill both -expand 1
