@@ -109,7 +109,7 @@ pack .actions
 }
 
 proc setupdisplay {} {
-global projects activities display_prevday activeactions
+global activities display_prevday activeactions
 global allcontacts
 global num_today_actions history_win_depth current_win_depth
 global version
@@ -178,6 +178,7 @@ menu .mBar.reports.m
 .mBar.reports.m add command -label [mc "Total time for a project"] -command doTotalTimeForProject
 .mBar.reports.m add command -label [mc "Project Progress Report"] -command doProjectProgressReport
 .mBar.reports.m add command -label [mc "Interruptions Report"] -command doInterruptionsReport
+.mBar.reports.m add command -label [mc "Active and Pending Actions"] -command doActiveAndPendingReport
 .mBar.reports.m add separator
 .mBar.reports.m add command -label [mc "Help"] -command "taghelp reports"
 
