@@ -45,6 +45,21 @@ package provide tag 0.1
 #		of fieldname. It tekes the same options as the lsort command
 #
 
+proc tag_entryVal { entry attribName } {
+# return the value of a given item out of a tag entry
+#
+#  entry - an entry in a tag file as a TCL list
+#  attribName - the name of the attribute to be returned
+#
+# Based on logEdit_tagVal by Alexander Spanke
+   foreach i $entry {
+       if {[lindex $i 0] == $attribName} {
+        return [lindex $i 1]
+      }
+   }
+   return ""
+}
+ 
 
 proc tag { action args } {
 
@@ -575,6 +590,10 @@ foreach item $entry {
 	}
    } elseif { $testop == "-contains"} {
    # return true if the tagvalue contains the string given as a testvalue
+   # Note - Do not optimise this by an early return if the label is found
+   #  but the value does not match, as it could be that the label occurs
+   #  more than once (is used that way in taglog_project
+   #  for the flags
 	if { $testlabel == $tagname } {
 	set testvalue [lindex $test 2]
 	if { [string match -nocase  *$testvalue* $tagvalue] } {
@@ -720,6 +739,52 @@ foreach item $entry {
  set entry [linsert $entry $len $newitem]
  return 0
 
+} elseif {$action == "setorreplaceflags" } {
+# Similar to  setorreplace, but the entryvar points to a set of flags
+#  tag setorreplaceflags entryvar name flag value
+#  e.g. tag setorrplaceflags proj Flags Active 0
+#
+#  If value is set to 1 then works like addorreplace and will add a Flags
+#   entry set to Active (or not if not needed)
+#  If value is set to 0 then remove any Flags entries which only contain
+#   the Active value (and later will remove it from comma seperated list)
+#
+set entryvar [lindex $args 0 ]
+set name [lindex $args 1 ]
+set flag [lindex $args 2]
+set newvalue [lindex $args 3 ]
+
+upvar $entryvar entry
+
+set i 0
+foreach item $entry {
+ set tagname [lindex $item 0]
+ set tagvalue [lindex $item 1]
+ if { (( $name == $tagname) && ( $tagvalue == $flag)) } {
+     if { $newvalue } {
+        # We want the value to exist
+           # It already exists - return
+           return 0
+        } else {
+        # We want to take it out if it matches this entry
+         set entry [lreplace $entry $i $i]
+         return 0
+        }
+     }
+ incr i
+}
+
+
+# we got here and we did not find the tag we wanted - add it to the end
+# but only if newvalue is true
+if { $newvalue } {
+ set newitem [list $name $flag]
+ set len [llength $entry]
+ incr len -1
+ set entry [linsert $entry $len $newitem]
+ }
+ return 0
+
 } elseif { $action == "update" } {
 #
 #  tag update filename replacement_entry id_field
