@@ -118,7 +118,7 @@ destroy $w
 proc actionInputWindow { mode {winnum 0} {idvar ""} } {
 global actin_f_a
 global hh mm ss year month day
-global validStates projects
+global validStates
 global scrollside
 global allcontacts
 global currentProject
@@ -228,25 +228,26 @@ actin_setup_field $w $winnum $mode Id actin_f_a($winnum,Id) $lw 40 string actinp
 actin_setup_field $w $winnum $mode Title actin_f_a($winnum,Title) $lw 40 string actinput_title ""
 
 # set the first active project to be the current project
-lappend activeproj $currentProject
-for { set i 0 } {$i < [llength $projects]} {incr i} {
- if { ! [projclosed [lindex [lindex $projects $i] 0]] } {
- lappend activeproj [lindex [lindex $projects $i] 0]
- }
-}
+if { $currentProject != "" } {
+   lappend activeproj $currentProject
+   set activeproj [concat $activeproj [taglog_getList proj]]
+   } else {
+     set activeproj [taglog_getList proj]
+   }
+#for { set i 0 } {$i < [llength $projects]} {incr i} {
+# if { ! [projclosed [lindex [lindex $projects $i] 0]] } {
+# lappend activeproj [lindex [lindex $projects $i] 0]
+# }
+#}
 actin_setup_field $w $winnum $mode Project actin_f_a($winnum,Project) $lw 40 selection actinput_project "" $activeproj $activeproj
 
 actin_setup_field $w $winnum $mode Date actin_f_a($winnum,Date) $lw 40 string actinput_date "$year-$month-$day $hh:$mm"
 
 actin_setup_field $w $winnum $mode Priority actin_f_a($winnum,Priority) $lw 40 selection actinput_priority 50 {10 20 30 40 50 60 70 80 90} {10 20 30 40 50 60 70 80 90}
 
-#%%%%%%%%%% translate "valideStates %%%%%%%%%%%%%%%%
-# PROBLEM: the translation of the menu entries can be translated
-# but in the entry widget the English text is displayed
 foreach i $validStates {
   lappend vStates [mc $i]
 }
-#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 actin_setup_field $w $winnum $mode Status actin_f_a($winnum,Status) $lw 40 selection actinput_status Pending $vStates $validStates
 
 actin_setup_field $w $winnum $mode Expected-cost actin_f_a($winnum,Expected-cost) $lw 40 string actinput_expected_cost ""
@@ -514,42 +515,14 @@ proc doactviewOK {} {
 destroy .actview
 }
 
-proc doactviewSaveAsOK {} {
-global SaveAsFilename
-
-set f [ open $SaveAsFilename w ]
- puts $f [ .actview.main.body get 1.0 end ]
-
-close $f
-destroy .avsa
-}
-
 proc doactviewSaveAs {} {
 
-toplevel .avsa
-wm title .avsa [mc "Save Actions Display As ..."]
-
-frame .avsa.directory
-menubutton .avsa.directory.l -text [mc "Directory"] -menu .avsa.directory.l.m
-menu .avsa.directory.l.m
-# .avsa.directory.l.m add command -label "$public_dir"
-
-frame .avsa.filename
-menubutton .avsa.filename.label -text [mc "File name :"] -menu .avsa.filename.label.m
-menu .avsa.filename.label.m
-
-entry .avsa.filename.name -width 20 -relief sunken -textvariable SaveAsFilename
-pack .avsa.filename.label .avsa.filename.name -side left -in .avsa.filename
-pack .avsa.filename
-
-frame .avsa.bot
-button .avsa.bot.ok -text OK -command doactviewSaveAsOK
-button .avsa.bot.cancel -text [mc Cancel] -command { doCancel .avsa }
-pack .avsa.bot.ok .avsa.bot.cancel -side left
-pack .avsa.bot
-
-tkwait window .avsa
-
+set fn [tk_getSaveFile -defaultextension ".txt" ]
+ if { $fn != "" } {
+  set f [open $fn w]
+  puts $f [ .actview.main.body get 1.0 end ]
+  close $f
+ }
 }
 
 proc set_actsel_tests {} {
@@ -621,7 +594,7 @@ if { [info exists tests] } {
 proc editaction { actid {winnum 0} } {
 global actin_f_a
 global hh mm ss year month day
-global validStates projects
+global validStates
 global scrollside
 global allcontacts
 global allact allactstate
@@ -1148,7 +1121,6 @@ foreach item $action {
 }
 
 proc actSelect { okcommand } {
-global projects
 global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_maxpriority actsel_showfields actsel_filename actsel_filenames actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_id actsel_title actsel_projstat actsel_sortby
 
 proc setupActselProjMenu { varname index op } {
