@@ -11,7 +11,7 @@ package provide taglog_init 0.1
 proc initialise {} {
 global tcl_platform env
 global hh mm ss year month day currentStart currentEnd currentProject currentActivity logfilename \
- actionsfilename state projects projectsfilename activities rootdir currentAction
+ actionsfilename state projectsfilename activities rootdir currentAction
 global currentContact
 global contactsfilename
 global contacttypes
@@ -141,7 +141,6 @@ set projects_url ""
 
 set contacttypes { colleague customer supplier contact friend }
 
-set projects {}
 set rate ""
 
 set activities { phone-in phone-out meeting meeting-preparation meeting-review email reading programming writing thinking service-break informal-discussion }
@@ -391,11 +390,13 @@ if {  [can_get_httprojects] } {
 
 #fill up the activity list
 
+if {[file readable $activitiesfilename]} {
 set fileid [open $activitiesfilename  r+]
 seek $fileid 0 start
 set buffer [read $fileid];
 close $fileid
 set activities [split $buffer "\n"];
+}
 
 savePrefs
 
@@ -518,6 +519,11 @@ menubutton .editprefs.language.l -text [mc Language] -menu .editprefs.language.l
 menu .editprefs.language.l.m
 .editprefs.language.l.m add command -label "English (en)" -command "set editprefs_language en"
 .editprefs.language.l.m add command -label "Deutsch (de)" -command "set editprefs_language de"
+.editprefs.language.l.m add command -label "Español (es) (minimal)" -command "set editprefs_language es"
+.editprefs.language.l.m add command -label "Francais (fr) (minimal)" -command "set editprefs_language fr"
+.editprefs.language.l.m add command -label "Ελληνικά (el) (minimal)" -command "set editprefs_language el"
+.editprefs.language.l.m add command -label "Italiano (it) (minimal)" -command "set editprefs_language it"
+.editprefs.language.l.m add command -label "Nederlands (nl) (minimal)" -command "set editprefs_language nl"
 .editprefs.language.l.m add separator
 .editprefs.language.l.m add command -label [mc Help] -command "taghelp prefs_language"
 entry .editprefs.language.v -textvariable editprefs_language
@@ -695,7 +701,6 @@ tkwait window .editprefs
 
 proc savePrefs {} {
 global prefsfile tcl_platform
-global projects
 global docdir
 global language
 global showtime_hours_per_day
@@ -729,7 +734,6 @@ if { $prefsfile !="" } {
 
  set f [open $prefsfile w]
  puts $f "$header"
-# puts $f "set projects \{$projects\}"
  puts $f "set language $language"
  puts $f "set showtime_hours_per_day $showtime_hours_per_day"
  puts $f "set docdir \"$docdir\""
@@ -765,7 +769,6 @@ if { $prefsfile !="" } {
   }
  set f [open $prefsfile w]
  puts $f "$header"
-#  puts $f "set projects \{$projects\}"
  puts $f "$marker"
  puts $f "$prev_prefs"
 
