@@ -9,13 +9,14 @@
 
 package provide taglog_project 0.1
 
-proc isbreak { projname } {
-# return true if the given project is a break project
-global projects
+proc proj_testflag { projname flagname } {
+# Test if a particular flag is set for a particular project
+global allproj 
 
-foreach proj $projects {
-if { [lindex $proj 0] == $projname } {
-  if { [lindex $proj 4] == 1 } {
+set test [list Flags "-contains" $flagname]
+foreach proj $allproj {
+if { [tag_entryVal $proj Name] == $projname } {
+  if { [tag matchcond $proj $test]} {
 	return 1
 	} else {
 	return 0
@@ -25,73 +26,61 @@ if { [lindex $proj 0] == $projname } {
 return 0
 }
 
+
+proc isbreak { projname } {
+# return true if the given project is a break project
+return [proj_testflag $projname Breaks]
+}
+
 proc isoverhead { projname } {
 # return true if the give project is an overhead project
-global projects
-
-foreach proj $projects {
-if { [lindex $proj 0] == $projname } {
-  if { [lindex $proj 3] == 1 } {
-	return 1
-	} else {
-	return 0
-	}
-  }
-}
-return 0
+return [proj_testflag $projname Overheads] 
 }
 
 proc isactive { projname } {
 # return true if the give project is an active project
-global projects
-
-foreach proj $projects {
-if { [lindex $proj 0] == $projname } {
-  if { [lindex $proj 7] == 1 } {
-	return 1
-	} else {
-	return 0
-	}
-  }
+return [proj_testflag $projname Active]
 }
-return 0
+
+proc isimmutable { projname } {
+# return true if the given project is immutable
+return [proj_testflag $projname Immutable]
 }
 
 
 proc getprojcode { projname } {
-# returns the project code asociated with the give project
-global projects
+# returns the project code asociated with the given project
+global allproj
 
-foreach proj $projects {
-if { [lindex $proj 0] == $projname } {
-  return [lindex $proj 2]
+foreach proj $allproj {
+if { [tag_entryVal $proj Name] == $projname } {
+  return [tag_entryVal $proj Code]
   }
 }
 return ""
 }
 
 proc getprojstart { projname } {
-global projects
-foreach proj $projects {
-if { [lindex $proj 0] == $projname } {
-   return [lindex $proj 5]
+global allproj 
+foreach proj $allproj {
+if { [tag_entryVal $proj Name] == $projname } {
+   return [tag_entryVal $proj StartDate]
   }
 }
 return ""
 }
 
 proc getprojend { projname } {
-global projects
-foreach proj $projects {
-if { [lindex $proj 0] == $projname } {
-   return [lindex $proj 6]
+global allproj 
+foreach proj $allproj {
+if { [tag_entryVal $proj Name] == $projname } {
+   return [tag_entryVal $proj EndDate]
    }
 }
 return ""
 }
 
 proc projclosed { projname } {
-global projects
  set enddate [getprojend $projname]
 if { $enddate != "" } {
  # check the date - there is probably some clever way of doing this with the
@@ -105,18 +94,18 @@ if { $enddate != "" } {
 } 
 
 proc incprojactindex { projname } {
-global projects
+global allproj 
 # increment the current actions index for a project and return the new value 
 set n 0
-foreach proj $projects {
-if { [lindex $proj 0] == $projname } {
-   set t [lindex $proj 1]
+foreach proj $allproj {
+if { [tag_entryVal $proj Name] == $projname } {
+   set t [tag_entryVal $proj NextActionId]
    if { $t == "" } {
 	set t 0
 	}
    incr t
-   set proj [lreplace $proj 1 1 $t]
-   set projects [lreplace $projects $n $n $proj]
+   tag setorreplace proj NextActionId $t
+   set allproj [lreplace $allproj $n $n $proj]
    writeprojects
    return $t
    }
@@ -125,19 +114,24 @@ if { [lindex $proj 0] == $projname } {
 return ""
 }
 
-proc proj_getDescription { proj } {
+proc proj_getDescription { projname } {
 global allproj
 
 }
 
-proc proj_setDescription { proj description } {
+proc proj_setDescription { projname description } {
 global allproj
 
 
 }
 
+proc proj_isImmutable { proj } {
+global allproj
 
 
+return 0
+}
+
 proc getProjTimes { files } {
 # Read the given files and return a list of  arrays giving the project times for# all the projects, with an extra array (first element ?) with the totals.
 
@@ -200,23 +194,48 @@ return $results
 
 
 proc addProjectOK {} {
-global addproject_name addproject_breaks addproject_overheads addproject_bookas addproject_active projects addproject_startdate addproject_enddate
+global addproject_name addproject_breaks addproject_overheads addproject_bookas addproject_active addproject_immutable addproject_startdate addproject_enddate
 global allproj
 
-set projects_entry [list $addproject_name 1 $addproject_bookas $addproject_overheads $addproject_breaks $addproject_startdate $addproject_enddate $addproject_active]
-lappend projects $projects_entry
+set endflag 1
+
+set thisproj ""
+set thisproj [tagappend $thisproj Name $addproject_name]
+set thisproj [tagappend $thisproj NextActionId 1]
+set thisproj [tagappend $thisproj Code $addproject_bookas]
+set thisproj [tagappend $thisproj StartDate $addproject_startdate]
+set thisproj [tagappend $thisproj EndDate $addproject_enddate]
+if { $addproject_overheads } {
+  set thisproj [tagappend $thisproj Flags Overheads]
+  }
+if { $addproject_breaks } {
+  set thisproj [tagappend $thisproj Flags Breaks]
+  }
+if { $addproject_active } {
+  set thisproj [tagappend $thisproj Flags Active]
+  }
+if { $addproject_immutable } {
+  set thisproj [tagappend $thisproj Flags Immutable]
+ }
+
+if { $endflag } {
+ set endpair [list End ]
+
+ lappend thisproj $endpair
+}
+
+
+lappend allproj $thisproj
 # Also need to manually add a new projects menu entry
  .currentbar.project.menu add command -label $addproject_name \
 	-command "set currentProject \"$addproject_name\""
 
-# save preferences - though we may end up doing this on exit instead
-# savePrefs
  writeprojects
 destroy .addProject
 }
 
 proc doAddProject {} {
-global addproject_overheads addproject_breaks addproject_bookas projects addproject_startdate addproject_enddate addproject_active
+global addproject_overheads addproject_breaks addproject_bookas addproject_startdate addproject_enddate addproject_active addproject_immutable
 
 toplevel .addProject
 wm title .addProject [mc "Add a new project"]
@@ -234,16 +253,13 @@ set addproject_overheads 0
 checkbutton .addProject.flags.overheads -text [mc "Book as overheads"] -variable addproject_overheads
 set addproject_active 1
 checkbutton .addProject.flags.active -text [mc "Project is active"] -variable addproject_active
-pack .addProject.flags.breaks .addProject.flags.overheads .addProject.flags.active -in .addProject.flags
+set addproject_immutable 0
+checkbutton .addProject.flags.immutable -text [mc "Project is immutable"] -variable addproject_immutable
+pack .addProject.flags.breaks .addProject.flags.overheads .addProject.flags.active .addProject.flags.immutable -in .addProject.flags
 pack .addProject.flags
 
 frame .addProject.projcode
 label .addProject.projcode.project -text [mc "Booking Code"]
-#menubutton .addProject.projcode.project -text "Booking Code" -menu .addProject.bookas.project.m
-#menu .addProject.bookas.project.m
-#for { set i 0 } {$i < [llength $projects]} {incr i} 
-# .addProject.bookas.project.m add command -label [lindex [lindex $projects $i] 0] \
-#	-command "set addproject_bookas \"[lindex [lindex $projects $i] 0]\""
 entry .addProject.projcode.projentry -width 20 -textvariable addproject_bookas
 pack .addProject.projcode.project .addProject.projcode.projentry -in .addProject.projcode -side left
 pack .addProject.projcode
@@ -272,45 +288,53 @@ tkwait window .addProject
 }
 
 proc doEditProjectsOK {} {
-global projects
-global epbreaks epoverheads epbookas epdelete epstart epend epactive
+
+global allproj
+global epbreaks epoverheads epbookas epdelete epstart epend epactive epimmutable
 
 
 set n 0
 set projindex 0
-foreach proj $projects {
+foreach proj $allproj {
 
 if {$epdelete($n)} {
- set projects [lreplace $projects $projindex $projindex]
+ set allproj [lreplace $allproj $projindex $projindex]
  incr n
 } else {
-
-# Insure against old project files with less elements
- while  {[ llength $proj] <8 } {
-   lappend proj ""
- }
  
+#  The tricky part about the flags is that we do not want to keep
+#   adding to them, and we want to be able to unset them too
+#
 
- set proj [lreplace $proj 4 4 $epbreaks($n) ]
- set proj [lreplace $proj 3 3 $epoverheads($n) ]
- set proj [lreplace $proj 2 2 $epbookas($n)]
- set proj [lreplace $proj 5 5 $epstart($n)]
- set proj [lreplace $proj 6 6 $epend($n)]
- set proj [lreplace $proj 7 7 $epactive($n)]
- set projects [lreplace $projects $projindex $projindex $proj]
+# set proj [lreplace $proj 4 4 $epbreaks($n) ]
+ tag setorreplaceflags proj Flags Breaks $epbreaks($n)
+# set proj [lreplace $proj 3 3 $epoverheads($n) ]
+ tag setorreplaceflags proj Flags Overheads $epoverheads($n)
+# set proj [lreplace $proj 2 2 $epbookas($n)]
+ tag setorreplace proj Code $epbookas($n)
+# set proj [lreplace $proj 5 5 $epstart($n)]
+ tag setorreplace proj StartDate $epstart($n)
+# set proj [lreplace $proj 6 6 $epend($n)]
+ tag setorreplace proj EndDate $epend($n)
+# set proj [lreplace $proj 7 7 $epactive($n)]
+ tag setorreplaceflags proj Flags Active $epactive($n)
+ tag setorreplaceflags proj Flags Immutable $epimmutable($n)
+# set projects [lreplace $projects $projindex $projindex $proj]
+ set allproj [lreplace $allproj $projindex $projindex $proj]
 
 incr n
 incr projindex
 }
 }
 
+#writeprojects_old
 writeprojects
 destroy .ep
 }
 
 proc doEditProjects {} {
-global projects
-global epbreaks epoverheads epbookas epdelete epstart epend epactive
+global allproj
+global epbreaks epoverheads epbookas epdelete epstart epend epactive epimmutable
 
 toplevel .ep
 wm title .ep [mc "Edit Projects"]
@@ -323,9 +347,11 @@ frame .ep.top.flags
 label .ep.top.flags.breaks -text [mc Breaks]
 label .ep.top.flags.overheads -text [mc Overheads]
 label .ep.top.flags.active -text [mc Active]
+label .ep.top.flags.immutable -text [mc Immutable]
 pack .ep.top.flags.breaks  -in .ep.top.flags -anchor w
 pack .ep.top.flags.overheads -in .ep.top.flags 
 pack .ep.top.flags.active -in .ep.top.flags -anchor e
+pack .ep.top.flags.immutable -in .ep.top.flags -anchor e
 
 label .ep.top.code -text [mc Code]
 label .ep.top.dates -text [mc Dates] -width 45
@@ -350,51 +376,57 @@ set f [frame .ep.m.c.f -bd 0]
 
 
 set n 0
-foreach proj $projects {
+foreach proj $allproj {
+ set pname [tag_entryVal $proj Name]
 
 frame .ep.m.c.f.p$n
-label .ep.m.c.f.p$n.p -text [lindex $proj 0] -width 20
+label .ep.m.c.f.p$n.p -text $pname -width 20
 set epbreaks($n) 0
-if { [isbreak [lindex $proj 0]] } {
+if { [isbreak $pname] } {
         set epbreaks($n) 1
         }
-#checkbutton .ep.m.c.f.p$n.breaks -text [mc "Breaks"] -variable epbreaks($n) 
 checkbutton .ep.m.c.f.p$n.breaks -variable epbreaks($n) 
 
 pack .ep.m.c.f.p$n.p -side left
 pack .ep.m.c.f.p$n.breaks -side left -fill x
 
 set epoverheads($n) 0
-if { [isoverhead [lindex $proj 0]] } {
+if { [isoverhead $pname] } {
 	set epoverheads($n) 1
 }
-#checkbutton .ep.m.c.f.p$n.overheads -text "Overheads" -variable epoverheads($n)
 checkbutton .ep.m.c.f.p$n.overheads -variable epoverheads($n)
 pack .ep.m.c.f.p$n.overheads -side left -fill x
 
 set epactive($n) 0
-if {[isactive [lindex $proj 0]] } {
+if {[isactive $pname] } {
   set epactive($n) 1
 }
 checkbutton .ep.m.c.f.p$n.active -variable epactive($n)
 pack .ep.m.c.f.p$n.active -side left -fill x
 
-set epbookas($n) [getprojcode [lindex $proj 0]]
+set epimmutable($n) 0
+if {[isimmutable $pname] } {
+  set epimmutable($n) 1
+}
+checkbutton .ep.m.c.f.p$n.immutable -variable epimmutable($n)
+pack .ep.m.c.f.p$n.immutable -side left -fill x
+
+set epbookas($n) [getprojcode $pname]
 label .ep.m.c.f.p$n.bookasmenu -text "Code"
 pack .ep.m.c.f.p$n.bookasmenu -side left -fill x
 entry .ep.m.c.f.p$n.bookas -width 10 -textvariable epbookas($n)
 pack .ep.m.c.f.p$n.bookas -side left -fill x
 
 
-set epstart($n) [getprojstart [lindex $proj 0]]
-menubutton .ep.m.c.f.p$n.startlab -text "Start" -menu .ep.m.c.f.p$n.startlab.m
+set epstart($n) [getprojstart $pname]
+menubutton .ep.m.c.f.p$n.startlab -text [mc "Start"] -menu .ep.m.c.f.p$n.startlab.m
 menu .ep.m.c.f.p$n.startlab.m
 calUtil_menu .ep.m.c.f.p$n.startlab.m .ep.m.c.f.p$n.starten
 pack .ep.m.c.f.p$n.startlab -side left -fill x
 entry .ep.m.c.f.p$n.starten -width 10 -textvariable epstart($n)
 pack .ep.m.c.f.p$n.starten -side left -fill x
 
-set epend($n) [getprojend [lindex $proj 0]]
+set epend($n) [getprojend $pname]
 menubutton .ep.m.c.f.p$n.endlab -text [mc "End "] -menu .ep.m.c.f.p$n.endlab.m
 menu .ep.m.c.f.p$n.endlab.m
 set todayiso [clock format [clock seconds] -format "%Y-%m-%d"]
@@ -446,14 +478,15 @@ tkwait window .ep
 
 proc initProjTimes {} {
 global projTimes projTimesTotal projTimesTotalNonBreaks
-global projects
+global allproj
 
 set projTimesTotal "00:00"
 set projTimesTotalNonBreaks "00:00"
 
+
 # initialise the projTimes array
-foreach proj $projects {
- set projname [lindex $proj 0]
+foreach proj $allproj {
+ set projname [tag_entryVal $proj Name]
  if {[isactive $projname] } {
    if { ![info exists projTimes($projname)] } {
      set projTimes($projname) "00:00"
@@ -541,24 +574,48 @@ trace vdelete currentProject w highlightActiveProjButton
 
 }
 
+# -- setupProjMenu
+#
+# Set up a tk menu, which will present a set of projects and allow a variable
+#  to be set according to the project which is selected.
+#
+# Arguments
+#   menuname: the name of the menu (e.g. .winname.select.proj
+#   varname:  the name of the variable receive the project name
+#   projstat: "all" if all projects are to be returned, otherwise "" for
+#               active projects only.
+#   helpdest: Id of the help entry or "" for no help entry.
+#
+
 proc setupProjMenu { menuname varname projstat helpdest } {
-global projects
+global allproj 
 
 $menuname delete 1 end
 
 $menuname add command -label "--" -command "set $varname  \"\""
-for { set i 0 } {$i < [llength $projects]} {incr i} {
- if { $projstat == "all" ||  ! [projclosed [lindex [lindex $projects $i] 0]] } {
- $menuname add command -label [lindex [lindex $projects $i] 0] \
-	-command "set $varname \"[lindex [lindex $projects $i] 0]\""
+foreach proj $allproj {
+ set pname [tag_entryVal $proj Name]
+ if {$pname != ""} {
+ if { $projstat == "all" ||  ! [projclosed $pname] } {
+ $menuname add command -label $pname \
+	-command "set $varname \"$pname\""
 }
 }
+}
+
+if { $helpdest != "" } {
 $menuname add separator
 $menuname add command -label [mc Help] -command "taghelp $helpdest"
 }
-
+}
 
 proc writeprojects {} {
+global allproj projectsfilename
+
+ tag writefile $projectsfilename $allproj
+}
+
+proc writeprojects_old {} {
 global projects projectsfilename
 # for now this is more complex than writeactions because we have the projects
 # in a tcl list which is not in tagged format.
@@ -646,7 +703,7 @@ if { ![info exists projects] } { set projects {} }
 proc readprojects {} {
 
 global projects projectsfilename allproj
-# Note that projects is not in tagged list format
+# Note that projects is not in tagged list format, but allproj is.
 
 set allproj [tag readfile $projectsfilename]
 if { [ llength $allproj] == 0 } {
@@ -664,7 +721,7 @@ if { [ llength $allproj] == 0 } {
 if {[info exists projects] } {
 # puts "projects is $projects"
  if { [llength $projects] != 0 } {
- writeprojects
+ writeprojects_old
  savePrefs
  return
  }
