@@ -166,15 +166,14 @@ tkwait window .totalprojtimesres
 }
 
 proc TotalTimeForProjectProjSel { project } {
-global projects totalprojtimessel_project totalprojtimessel_startdate totalprojtimessel_enddate
+global totalprojtimessel_project totalprojtimessel_startdate totalprojtimessel_enddate
   set totalprojtimessel_project $project
   set totalprojtimessel_startdate [getprojstart $project]
   set totalprojtimessel_enddate [getprojend $project] 
 }
 
 proc doTotalTimeForProject { } {
-global projects totalprojtimessel_project
-
+global allproj totalprojtimessel_project
 
 toplevel .totalprojtimes
 wm title .totalprojtimes [mc "Enter Project details"]
@@ -183,9 +182,10 @@ frame .totalprojtimes.selproj.p
 menubutton .totalprojtimes.selproj.p.project -text [mc Project] -menu .totalprojtimes.selproj.p.project.m
 menu .totalprojtimes.selproj.p.project.m
 .totalprojtimes.selproj.p.project.m add command -label "--" -command "set totalprojtimessel_project \"\""
-for { set i 0 } {$i < [llength $projects]} {incr i} {
-  .totalprojtimes.selproj.p.project.m add command -label [lindex [lindex $projects $i] 0] \
-  -command "TotalTimeForProjectProjSel \"[lindex [lindex $projects $i] 0]\""
+foreach proj $allproj {
+   set pname [tag_entryVal $proj Name] 
+  .totalprojtimes.selproj.p.project.m add command -label $pname \
+  -command "TotalTimeForProjectProjSel \"$pname\""
 } 
 entry .totalprojtimes.selproj.p.projectentry -textvariable totalprojtimessel_project -width 20
 pack .totalprojtimes.selproj.p.project .totalprojtimes.selproj.p.projectentry -in .totalprojtimes.selproj.p -side left
@@ -424,7 +424,7 @@ proc firstDayOfWeek { weekno year } {
 # what day of the week is the first
 set firstday [clock format [clock scan "1 jan $year"] -format "%w"]
 # puts "first day is $firstday"
-if { $firstday < 4 } { incr firstday 7 }
+if { $firstday <= 4 } { incr firstday 7 }
 #set offset [expr { ( 8- $firstday ) %7 } ]
 set offset [expr { 1- $firstday } ]
 # puts "offset is $offset"
@@ -486,6 +486,7 @@ set booked_projects {}
 set total_overheads "00:00:00"
 set nonbreakstotal "00:00:00"
 set breakstotal "00:00:00"
+set immutabletotal "00:00:00"
 
 
 # Clear all the arrays used for totals
@@ -500,6 +501,11 @@ if [ info exists daytotal ] {
  unset daytotal
 }
 
+if [ info exists dayimmutable] {
+ unset dayimmutable
+}
+
+
 # Work out the times for all the projects in all the files
 set projtotals(empty) "00:00"
 
@@ -565,6 +571,11 @@ unset projtimes${day}
  inctime projtotals($displayname) $duration
  inctime daytotal($day) $duration
  inctime nonbreakstotal $duration
+
+ if { [isimmutable $thisproject] } {
+   inctime immutabletotal $duration
+   inctime dayimmutable($day) $duration
+   }
   }
 
  set thisproject unknown
@@ -603,15 +614,18 @@ if { $showtime_spreadoverheads } {
 
 set totalmins [ timediff "00:00" $nonbreakstotal ]
 set overheadmins [ timediff "00:00" $total_overheads ]
-set totalmins [ expr { $totalmins - $overheadmins } ]
+set immutablemins [ timediff "00:00" $immutabletotal ]
+set totalmins [ expr { $totalmins - $overheadmins - $immutablemins } ]
 # puts "Total mins is $totalmins"
 
 foreach thisproject $booked_projects {
+ if { ! [isimmutable $thisproject ] } {
 # puts "project is $thisproject Total time is $projtotals($thisproject)"
  set projmins [ timediff "00:00" $projtotals($thisproject) ]
 # puts "Projmins is $projmins"
  set projfraction($thisproject) [expr { ( $projmins * 1.0)  / $totalmins } ] 
 # puts "Fraction of the time spent on this project is $projfraction($thisproject)"
+ }
 
 }
 
@@ -648,12 +662,14 @@ set displayproj [string range $thisproject 0 18]
 
 for { set day $startday } {$day < [expr {$startday+7}]} { incr day } {
 if { $showtime_spreadoverheads && [ info exists dayoverheads($day)]  } {
+ if { ! [isimmutable $thisproject]} {
 # redistribute the spare minutes (or seconds now that we work in them)
  set secstospread [timediff "00:00"  $dayoverheads($day)]
  set secsthisproj [ expr { round( $secstospread * $projfraction($thisproject))}]
 # puts "We have  $dayoverheads($day) = $minstospread minutes to spread _ $minsthisproj"
  inctime projtimes${day}($thisproject) $secsthisproj
  inctime projtotals($thisproject) $secsthisproj
+}
 
 }
 }
@@ -889,7 +905,7 @@ tkwait window .timebyact
 }
 
 proc doProjectProgressReport {} {
-global projects projrepinfosel_project projrepinfosel_start projrepinfosel_end 
+global projrepinfosel_project projrepinfosel_start projrepinfosel_end 
 
 toplevel .projrepinfo
 wm title .projrepinfo [mc "Enter information for Project Progress Report"]
@@ -899,11 +915,7 @@ frame .projrepinfo.selproj
 frame .projrepinfo.selproj.p
 menubutton .projrepinfo.selproj.p.project -text [mc Project] -menu .projrepinfo.selproj.p.project.m
 menu .projrepinfo.selproj.p.project.m
-.projrepinfo.selproj.p.project.m add command -label "--" -command "set totalprojtimessel_project \"\""
-for { set i 0 } {$i < [llength $projects]} {incr i} {
-  .projrepinfo.selproj.p.project.m add command -label [lindex [lindex $projects $i] 0] \
-  -command "set projrepinfosel_project  \"[lindex [lindex $projects $i] 0]\""
-} 
+setupProjMenu .projrepinfo.selproj.p.project.m projrepinfosel_project "all" "" 
 entry .projrepinfo.selproj.p.projectentry -textvariable projrepinfosel_project -width 20
 pack .projrepinfo.selproj.p.project .projrepinfo.selproj.p.projectentry -in .projrepinfo.selproj.p -side left
 pack .projrepinfo.selproj.p
@@ -959,6 +971,8 @@ wm title .projrep "[mc {Project Progress Report for}] $proj"
   set f [open $fn w]
   puts $f "<head>"
   puts $f "<title>[mc {Project Progress Report for}] $proj</title>"
+ } else {
+   return
  }
 
 }
@@ -1306,3 +1320,31 @@ tkwait window .intrep
 
 }
 
+proc doActiveAndPendingReport {} {
+# Report on active and pending actions.
+global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_sortby
+global actsel_id actsel_title
+global actsel_filename actionsfilename
+
+set actsel_project ""
+set actsel_st_any 0
+set actsel_st_unclaimed 0
+set actsel_st_pending 1
+set actsel_st_active 1
+set actsel_st_blocked 1
+set actsel_st_delegated 0
+set actsel_st_compeleted 0
+set actsel_st_aborted 0
+set actsel_showfields(all) 1
+set actsel_maxpriority ""
+set actsel_expected_start ""
+set actsel_expected_completed ""
+set actsel_sortby "Priority"
+set actsel_id ""
+set actsel_title ""
+set actsel_filename $actionsfilename
+
+displayActions 
+
+}
+
